import * as create from 'create';
import { BaseOptionsFor } from 'create';
import { z } from 'zod';

declare const base: create.Base<{
    access: z.ZodUnion<[z.ZodLiteral<"public">, z.ZodLiteral<"restricted">]>;
    author: z.ZodOptional<z.ZodString>;
    bin: z.ZodOptional<z.ZodString>;
    contributors: z.ZodOptional<z.ZodArray<z.ZodObject<{
        avatar_url: z.ZodString;
        contributions: z.ZodArray<z.ZodString, "many">;
        login: z.ZodString;
        name: z.ZodString;
        profile: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        name: string;
        avatar_url: string;
        contributions: string[];
        login: string;
        profile: string;
    }, {
        name: string;
        avatar_url: string;
        contributions: string[];
        login: string;
        profile: string;
    }>, "many">>;
    description: z.ZodDefault<z.ZodString>;
    directory: z.ZodString;
    documentation: z.ZodOptional<z.ZodString>;
    email: z.ZodEffects<z.ZodUnion<[z.ZodString, z.ZodObject<{
        github: z.ZodString;
        npm: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        github: string;
        npm: string;
    }, {
        github: string;
        npm: string;
    }>]>, {
        github: string;
        npm: string;
    }, string | {
        github: string;
        npm: string;
    }>;
    funding: z.ZodOptional<z.ZodString>;
    guide: z.ZodOptional<z.ZodObject<{
        href: z.ZodString;
        title: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        href: string;
        title: string;
    }, {
        href: string;
        title: string;
    }>>;
    hideTemplatedBy: z.ZodOptional<z.ZodBoolean>;
    keywords: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    logo: z.ZodOptional<z.ZodObject<{
        alt: z.ZodString;
        height: z.ZodOptional<z.ZodNumber>;
        src: z.ZodString;
        width: z.ZodOptional<z.ZodNumber>;
    }, "strip", z.ZodTypeAny, {
        alt: string;
        src: string;
        height?: number | undefined;
        width?: number | undefined;
    }, {
        alt: string;
        src: string;
        height?: number | undefined;
        width?: number | undefined;
    }>>;
    node: z.ZodOptional<z.ZodObject<{
        minimum: z.ZodString;
        pinned: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        minimum: string;
        pinned?: string | undefined;
    }, {
        minimum: string;
        pinned?: string | undefined;
    }>>;
    owner: z.ZodString;
    packageData: z.ZodOptional<z.ZodObject<{
        dependencies: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        devDependencies: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        scripts: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        dependencies?: Record<string, string> | undefined;
        devDependencies?: Record<string, string> | undefined;
        scripts?: Record<string, string> | undefined;
    }, {
        dependencies?: Record<string, string> | undefined;
        devDependencies?: Record<string, string> | undefined;
        scripts?: Record<string, string> | undefined;
    }>>;
    repository: z.ZodString;
    title: z.ZodString;
    usage: z.ZodOptional<z.ZodString>;
    version: z.ZodOptional<z.ZodString>;
}>;
type BaseOptions = BaseOptionsFor<typeof base>;

export { type BaseOptions, base };
