var name = "create-typescript-app";
var version = "2.0.0-beta.5";
var description = "Quickstart-friendly TypeScript template with comprehensive, configurable, opinionated tooling. 🎁";
var repository = {
	type: "git",
	url: "git+https://github.com/JoshuaKGoldberg/create-typescript-app.git"
};
var license = "MIT";
var author = {
	name: "Josh Goldberg ✨",
	email: "npm@joshuakgoldberg.com"
};
var type = "module";
var main = "./lib/index.js";
var bin = "./bin/index.js";
var files = [
	"LICENSE.md",
	"README.md",
	"bin/index.js",
	"lib/",
	"package.json"
];
var scripts = {
	build: "tsup",
	format: "prettier .",
	initialize: "pnpm build --no-dts && tsx ./bin/index.js --mode initialize",
	lint: "eslint . --max-warnings 0",
	"lint:knip": "knip",
	"lint:md": "markdownlint \"**/*.md\" \".github/**/*.md\" --rules sentences-per-line",
	"lint:packages": "pnpm dedupe --check",
	"lint:spelling": "cspell \"**\" \".github/**/*\"",
	prepare: "husky",
	test: "vitest",
	"test:create": "npx tsx script/create-test-e2e.ts",
	"test:initialize": "npx tsx script/initialize-test-e2e.ts",
	"test:migrate": "vitest run -r script/",
	tsc: "tsc"
};
var dependencies = {
	"@clack/prompts": "^0.9.0",
	"@prettier/sync": "^0.5.2",
	chalk: "^5.4.1",
	create: "0.1.0-alpha.11",
	"cspell-populate-words": "^0.3.0",
	execa: "^9.5.2",
	"git-remote-origin-url": "^4.0.0",
	"git-url-parse": "^16.0.0",
	"html-to-text": "^9.0.5",
	"image-size": "^1.2.0",
	"input-from-file": "0.1.0-alpha.4",
	"input-from-file-json": "0.1.0-alpha.4",
	"input-from-script": "0.1.0-alpha.4",
	"js-yaml": "^4.1.0",
	"lazy-value": "^3.0.0",
	"npm-user": "^6.1.1",
	"object-strings-deep": "^0.1.1",
	octokit: "^4.0.2",
	"octokit-from-auth": "^0.3.0",
	"parse-author": "^2.0.0",
	"parse-package-name": "^1.0.0",
	"populate-all-contributors-for-repository": "^0.1.2",
	prettier: "^3.4.2",
	"remove-undefined-objects": "^5.0.0",
	"replace-in-file": "^8.3.0",
	rimraf: "^6.0.1",
	"set-github-repository-labels": "^0.1.0",
	"sort-package-json": "^2.12.0",
	"title-case": "^4.3.2",
	zod: "^3.24.1",
	"zod-validation-error": "^3.4.0"
};
var devDependencies = {
	"@eslint-community/eslint-plugin-eslint-comments": "4.4.1",
	"@eslint/js": "9.17.0",
	"@octokit/request-error": "6.1.5",
	"@release-it/conventional-changelog": "9.0.3",
	"@types/eslint-plugin-markdown": "2.0.2",
	"@types/git-url-parse": "9.0.3",
	"@types/html-to-text": "9.0.4",
	"@types/js-yaml": "4.0.9",
	"@types/node": "22.10.2",
	"@types/parse-author": "2.0.3",
	"@vitest/coverage-v8": "2.1.8",
	"@vitest/eslint-plugin": "1.1.20",
	"all-contributors-cli": "6.26.1",
	c8: "10.1.3",
	"console-fail-test": "0.5.0",
	"create-testers": "0.1.0-alpha.11",
	cspell: "8.17.1",
	eslint: "9.17.0",
	"eslint-plugin-jsdoc": "50.6.1",
	"eslint-plugin-jsonc": "2.18.2",
	"eslint-plugin-markdown": "5.1.0",
	"eslint-plugin-n": "17.15.1",
	"eslint-plugin-package-json": "0.19.0",
	"eslint-plugin-perfectionist": "4.4.0",
	"eslint-plugin-regexp": "2.7.0",
	"eslint-plugin-yml": "1.16.0",
	globby: "14.0.2",
	husky: "9.1.7",
	knip: "5.41.1",
	"lint-staged": "15.3.0",
	markdownlint: "0.37.2",
	"markdownlint-cli": "0.43.0",
	"prettier-plugin-curly": "0.3.1",
	"prettier-plugin-packagejson": "2.5.6",
	"prettier-plugin-sh": "0.14.0",
	"release-it": "17.10.0",
	"sentences-per-line": "0.3.0",
	tsup: "8.3.5",
	tsx: "4.19.2",
	typescript: "5.7.2",
	"typescript-eslint": "8.19.0",
	vitest: "2.1.8"
};
var engines = {
	node: ">=18.3.0"
};
var publishConfig = {
	provenance: true
};
var _package = {
	name: name,
	version: version,
	description: description,
	repository: repository,
	license: license,
	author: author,
	type: type,
	main: main,
	bin: bin,
	files: files,
	scripts: scripts,
	"lint-staged": {
	"*": "prettier --ignore-unknown --write"
},
	dependencies: dependencies,
	devDependencies: devDependencies,
	engines: engines,
	publishConfig: publishConfig
};

declare const _________package_json_author: typeof author;
declare const _________package_json_bin: typeof bin;
declare const _________package_json_dependencies: typeof dependencies;
declare const _________package_json_description: typeof description;
declare const _________package_json_devDependencies: typeof devDependencies;
declare const _________package_json_engines: typeof engines;
declare const _________package_json_files: typeof files;
declare const _________package_json_license: typeof license;
declare const _________package_json_main: typeof main;
declare const _________package_json_name: typeof name;
declare const _________package_json_publishConfig: typeof publishConfig;
declare const _________package_json_repository: typeof repository;
declare const _________package_json_scripts: typeof scripts;
declare const _________package_json_type: typeof type;
declare const _________package_json_version: typeof version;
declare namespace _________package_json {
  export { _________package_json_author as author, _________package_json_bin as bin, _package as default, _________package_json_dependencies as dependencies, _________package_json_description as description, _________package_json_devDependencies as devDependencies, _________package_json_engines as engines, _________package_json_files as files, _________package_json_license as license, _________package_json_main as main, _________package_json_name as name, _________package_json_publishConfig as publishConfig, _________package_json_repository as repository, _________package_json_scripts as scripts, _________package_json_type as type, _________package_json_version as version };
}

declare const sourcePackageJson: typeof _________package_json;

export { sourcePackageJson };
